Authors
=======

All contributors retain copyright to their contributions. Below is a list of
authors who've contributed code to the project, or who wrote code elsewhere
that we reused here.

We manually track this since commit author *does not* equal code author.

* Benjamin Frank <ben+gitlab@pipsfrank.de>
* Christian Geier <geier@lostpackets.de>
* Guilhem Saurel <guilhem.saurel@gmail.com>
* Hugo Osvaldo Barrera <hugo@barrera.io>
* José Ribeiro <hello@jlbribeiro.com>
* Markus Unterwaditzer <markus@unterwaditzer.net>
* Thomas Glanzmann <thomas@glanzmann.de>
